Skip to main content Module ext Copy item path Source Expand description cmp stats load_average Returns the average value of the given external ID, ignoring unsuccessful reports. load_input Returns an iterator of raw data points for the given external ID, parsed into
the parameterized type using std::str::FromStr trait. Skip data points
with nonzero status OR cannot be parsed. load_input_raw Returns an iterator of raw reports for the given external ID with nonzero status. load_majority Returns the majority value of the given external ID, ignoring unsuccessful reports. load_median_float Returns the median value of the given external ID, ignoring unsuccessful reports. load_median_integer Returns the median value of the given external ID, ignoring unsuccessful reports.