Function owasm_kit::oei::get_execute_time
source · pub fn get_execute_time() -> i64Expand description
Return the execute block time during the call of execution phase. Must only be called during execution phase.
pub fn get_execute_time() -> i64Return the execute block time during the call of execution phase. Must only be called during execution phase.